Mary had a little lamb, 
Little lamb, little lamb,
Mary had a little lamb
Whose fleece was white as snow.

And everywhere that Mary went,
Mary went, Mary went,
Everywhere that Mary went 
The lamb was sure to go.

He followed her to school one day, 
School one day, school one day,
He followed her to school one day
Which was against the rules.

It made the children laugh and play,
Laugh and play, laugh and play,
It made the children laugh and play,
To see a lamb at school.

And so the teacher turned it out,
Turned it out, turned it out,
And so the teacher turned it out,
But still it lingered near,

He waited patiently about,
Patiently about, patiently about,
He waited patiently about,
Till Mary did appear.

"Why does the lamb love Mary so?
Love Mary so? Love Mary so?
Why does the lamb love Mary so?" 
The eager children cried.

"Why, Mary loves the lamb, you know,
Lamb, you know, lamb, you know,
Why, Mary loves the lamb, you know,"
The teacher did reply.
